==> jc-1.4.0.tar.gz: java/util/zip/InflaterHuffmanTree.h <==
// class java.util.zip.InflaterHuffmanTree

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class db8c3658d964533c java_util_zip_InflaterHuffmanTree

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_InflaterHuffmanTree_H_
#define _JC_java_util_zip_InflaterHuffmanTree_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_InflaterHuffmanTree$object;
struct _jc_java_util_zip_StreamManipulator$object;

// Typedefs
typedef struct _jc_java_util_zip_InflaterHuffmanTree$sub_refs	_jc_java_util_zip_InflaterHuffmanTree$sub_refs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs	_jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$refs	_jc_java_util_zip_InflaterHuffmanTree$refs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$nonrefs	_jc_java_util_zip_InflaterHuffmanTree$nonrefs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$object	_jc_java_util_zip_InflaterHuffmanTree$object;

typedef struct _jc_java_util_zip_InflaterHuffmanTree$fields_struct	_jc_java_util_zip_InflaterHuffmanTree$fields_struct;
typedef const struct _jc_java_util_zip_InflaterHuffmanTree$vmethods	_jc_java_util_zip_InflaterHuffmanTree$vmethods;
typedef const struct _jc_java_util_zip_InflaterHuffmanTree$vtable	_jc_java_util_zip_InflaterHuffmanTree$vtable;
typedef const struct _jc_java_util_zip_InflaterHuffmanTree$vtype	_jc_java_util_zip_InflaterHuffmanTree$vtype;

// Class fields structure
struct _jc_java_util_zip_InflaterHuffmanTree$fields_struct {
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*defDistTree;
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*defLitLenTree;
	jint	MAX__5fBITLEN;
};
extern _jc_java_util_zip_InflaterHuffmanTree$fields_struct _jc_java_util_zip_InflaterHuffmanTree$class_fields;

// Constructors
extern void _jc_java_util_zip_InflaterHuffmanTree$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_byte_array *);

// Virtual methods
extern void _jc_java_util_zip_InflaterHuffmanTree$method$buildTree$73a607fd349e0209(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_byte_array *);
extern jint _jc_java_util_zip_InflaterHuffmanTree$method$getSymbol$d74a166f3ddfd8f0(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_java_util_zip_StreamManipulator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_InflaterHuffmanTree$method_info$buildTree$73a607fd349e0209;
extern _jc_method _jc_java_util_zip_InflaterHuffmanTree$method_info$getSymbol$d74a166f3ddfd8f0;

// Static methods
extern void _jc_java_util_zip_InflaterHuffmanTree$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_util_zip_InflaterHuffmanTree$vmethods {
	void	(*buildTree$73a607fd349e0209)(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_byte_array *);
	jint	(*getSymbol$d74a166f3ddfd8f0)(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_java_util_zip_StreamManipulator$object *);
};

// Vtable
struct _jc_java_util_zip_InflaterHuffmanTree$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_InflaterHuffmanTree$vmethods	java_util_zip_InflaterHuffmanTree;
};

// Vtype
struct _jc_java_util_zip_InflaterHuffmanTree$vtype {
	_jc_type			type;
	_jc_java_util_zip_InflaterHuffmanTree$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_InflaterHuffmanTree$sub_refs {
	_jc_short_array	*tree;
};

// Reference instance fields (object)
struct _jc_java_util_zip_InflaterHuffmanTree$refs {
    _jc_java_util_zip_InflaterHuffmanTree$sub_refs	java_util_zip_InflaterHuffmanTree;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_InflaterHuffmanTree$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs	java_util_zip_InflaterHuffmanTree;
};

// Object instance structure
struct _jc_java_util_zip_InflaterHuffmanTree$object {
	_jc_java_util_zip_InflaterHuffmanTree$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_InflaterHuffmanTree$vtype	*vtype;
	_jc_java_util_zip_InflaterHuffmanTree$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_InflaterHuffmanTree$vtype _jc_java_util_zip_InflaterHuffmanTree$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_InflaterHuffmanTree, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_InflaterHuffmanTree$class_object;

#endif	/* _JC_java_util_zip_InflaterHuffmanTree_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/InflaterHuffmanTree.h <==
// class java.util.zip.InflaterHuffmanTree

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class db8c3658d964533c java_util_zip_InflaterHuffmanTree

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_InflaterHuffmanTree_H_
#define _JC_java_util_zip_InflaterHuffmanTree_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_InflaterHuffmanTree$object;
struct _jc_java_util_zip_StreamManipulator$object;

// Typedefs
typedef struct _jc_java_util_zip_InflaterHuffmanTree$sub_refs	_jc_java_util_zip_InflaterHuffmanTree$sub_refs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs	_jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$refs	_jc_java_util_zip_InflaterHuffmanTree$refs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$nonrefs	_jc_java_util_zip_InflaterHuffmanTree$nonrefs;
typedef struct _jc_java_util_zip_InflaterHuffmanTree$object	_jc_java_util_zip_InflaterHuffmanTree$object;

typedef struct _jc_java_util_zip_InflaterHuffmanTree$fields_struct	_jc_java_util_zip_InflaterHuffmanTree$fields_struct;
typedef const struct _jc_java_util_zip_InflaterHuffmanTree$vmethods	_jc_java_util_zip_InflaterHuffmanTree$vmethods;
typedef const struct _jc_java_util_zip_InflaterHuffmanTree$vtable	_jc_java_util_zip_InflaterHuffmanTree$vtable;
typedef const struct _jc_java_util_zip_InflaterHuffmanTree$vtype	_jc_java_util_zip_InflaterHuffmanTree$vtype;

// Class fields structure
struct _jc_java_util_zip_InflaterHuffmanTree$fields_struct {
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*defDistTree;
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*defLitLenTree;
	jint	MAX__5fBITLEN;
};
extern _jc_java_util_zip_InflaterHuffmanTree$fields_struct _jc_java_util_zip_InflaterHuffmanTree$class_fields;

// Constructors
extern void _jc_java_util_zip_InflaterHuffmanTree$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_zip_InflaterHuffmanTree$method$buildTree$73a607fd349e0209(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_java_util_zip_InflaterHuffmanTree$method$getSymbol$d74a166f3ddfd8f0(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_java_util_zip_StreamManipulator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_InflaterHuffmanTree$method_info$buildTree$73a607fd349e0209;
extern _jc_method _jc_java_util_zip_InflaterHuffmanTree$method_info$getSymbol$d74a166f3ddfd8f0;

// Static methods
extern void _jc_java_util_zip_InflaterHuffmanTree$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_zip_InflaterHuffmanTree$vmethods {
	void	(*buildTree$73a607fd349e0209)(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*getSymbol$d74a166f3ddfd8f0)(_jc_env *, struct _jc_java_util_zip_InflaterHuffmanTree$object *, struct _jc_java_util_zip_StreamManipulator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_InflaterHuffmanTree$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_InflaterHuffmanTree$vmethods	java_util_zip_InflaterHuffmanTree;
};

// Vtype
struct _jc_java_util_zip_InflaterHuffmanTree$vtype {
	_jc_type			type;
	_jc_java_util_zip_InflaterHuffmanTree$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_InflaterHuffmanTree$sub_refs {
	_jc_short_array	*tree;
};

// Reference instance fields (object)
struct _jc_java_util_zip_InflaterHuffmanTree$refs {
    _jc_java_util_zip_InflaterHuffmanTree$sub_refs	java_util_zip_InflaterHuffmanTree;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_InflaterHuffmanTree$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_InflaterHuffmanTree$sub_nonrefs	java_util_zip_InflaterHuffmanTree;
};

// Object instance structure
struct _jc_java_util_zip_InflaterHuffmanTree$object {
	_jc_java_util_zip_InflaterHuffmanTree$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_InflaterHuffmanTree$vtype	*vtype;
	_jc_java_util_zip_InflaterHuffmanTree$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_InflaterHuffmanTree$vtype _jc_java_util_zip_InflaterHuffmanTree$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_InflaterHuffmanTree, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_InflaterHuffmanTree$class_object;

#endif	/* _JC_java_util_zip_InflaterHuffmanTree_H_ */
